@@ -1,5 +1,9 @@
+extern crate easy_cargo_dep_B as B;
+use B::bbb::get_crate_name_and_version_of_B;
+
 pub fn get_crate_name_and_version_of_A() {
     let crate_name = env!("CARGO_PKG_NAME");
     let crate_version = env!("CARGO_PKG_VERSION");
     println!("line from crate \"{}\" and version is \"{}\"", crate_name, crate_version);
+    get_crate_name_and_version_of_B();
 }
\ No newline at end of file
